"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const fs_1 = require("fs");
const child_process_1 = require("child_process");
const path_1 = require("path");
const debug = debug_1.default('lisk:migrator');
const compiledConfig = 'migrator_compiled_config.json';
exports.isBinaryBuild = (corePath) => fs_1.existsSync(path_1.join(corePath, '.build'));
exports.getConfig = async (corePath, customConfigPath) => {
    const command = [];
    command.push(`cd ${corePath}`);
    if (exports.isBinaryBuild(corePath)) {
        command.push('&& source env.sh');
    }
    command.push('&& node scripts/generate_config.js');
    if (customConfigPath) {
        command.push(`--config ${customConfigPath}`);
    }
    command.push(`> ./${compiledConfig}`);
    const fullCommand = command.join(' ');
    const compiledConfigPath = path_1.join(corePath, compiledConfig);
    debug(`Core path: ${corePath}`);
    debug(`Cmd: ${fullCommand}`);
    cli_ux_1.default.action.start('Compiling Lisk Core configuration');
    child_process_1.execSync(fullCommand, { shell: '/bin/bash' });
    cli_ux_1.default.action.stop();
    cli_ux_1.default.action.start('Loading Lisk Core configuration');
    const config = await Promise.resolve().then(() => tslib_1.__importStar(require(compiledConfigPath)));
    cli_ux_1.default.action.stop();
    fs_1.unlinkSync(compiledConfigPath);
    return config;
};
//# sourceMappingURL=config.js.map